@@ -18,12 +18,12 @@ from oslo_concurrency import processutils as putils
 from oslo_log import log as logging
 
 from os_brick import exception
-from os_brick.i18n import _
+from os_brick import initiator
 from os_brick.initiator.connectors import base
 from os_brick import utils
 
 
-DEVICE_SCAN_ATTEMPTS_DEFAULT = 5
+DEVICE_SCAN_ATTEMPTS_DEFAULT = 3
 
 LOG = logging.getLogger(__name__)
 
@@ -34,15 +34,14 @@ class NVMeConnector(base.BaseLinuxConnector):
 
     """Connector class to attach/detach NVMe over fabric volumes."""
 
-    def __init__(self, root_helper, driver=None, use_multipath=False,
-                 device_scan_attempts=DEVICE_SCAN_ATTEMPTS_DEFAULT,
+    def __init__(self, root_helper, driver=None,
+                 device_scan_attempts=initiator.DEVICE_SCAN_ATTEMPTS_DEFAULT,
                  *args, **kwargs):
         super(NVMeConnector, self).__init__(
             root_helper,
             driver=driver,
             device_scan_attempts=device_scan_attempts,
             *args, **kwargs)
-        self.use_multipath = use_multipath
 
     @staticmethod
     def get_connector_properties(root_helper, *args, **kwargs):
@@ -61,28 +60,21 @@ class NVMeConnector(base.BaseLinuxConnector):
         nvme_devices = []
         pattern = r'/dev/nvme[0-9]n[0-9]'
         cmd = ['nvme', 'list']
-        for retry in range(1, self.device_scan_attempts + 1):
-            try:
-                (out, err) = self._execute(*cmd,
-                                           root_helper=self._root_helper,
-                                           run_as_root=True)
-                for line in out.split('\n'):
-                    result = re.match(pattern, line)
-                    if result:
-                        nvme_devices.append(result.group(0))
-                LOG.debug("_get_nvme_devices returned %(nvme_devices)s",
-                          {'nvme_devices': nvme_devices})
-                return nvme_devices
+        try:
+            (out, err) = self._execute(*cmd, root_helper=self._root_helper,
+                                       run_as_root=True)
+            for line in out.split('\n'):
+                result = re.match(pattern, line)
+                if result:
+                    nvme_devices.append(result.group(0))
+            LOG.debug("_get_nvme_devices returned %(nvme_devices)s",
+                      {'nvme_devices': nvme_devices})
+            return nvme_devices
 
-            except putils.ProcessExecutionError:
-                LOG.warning(
-                    "Failed to list available NVMe connected controllers, "
-                    "retrying.")
-                time.sleep(retry ** 2)
-        else:
-            msg = _("Failed to retrieve available connected NVMe controllers "
-                    "when running nvme list.")
-            raise exception.CommandExecutionFailed(message=msg)
+        except putils.ProcessExecutionError:
+            LOG.error(
+                "Failed to list available NVMe connected controllers.")
+            raise
 
     @utils.trace
     @synchronized('connect_volume')
@@ -121,12 +113,18 @@ class NVMeConnector(base.BaseLinuxConnector):
                 "%(conn_nqn)s", {'conn_nqn': conn_nqn})
             raise
 
-        all_nvme_devices = self._get_nvme_devices()
-        path = set(all_nvme_devices) - set(current_nvme_devices)
-        path = list(path)
-        if not path:
+        for retry in range(1, self.device_scan_attempts + 1):
+            all_nvme_devices = self._get_nvme_devices()
+            path = set(all_nvme_devices) - set(current_nvme_devices)
+            if path:
+                break
+            time.sleep(retry ** 2)
+        else:
+            LOG.error("Failed to retrieve available connected NVMe "
+                      "controllers when running nvme list")
             raise exception.TargetPortalNotFound(target_portal)
 
+        path = list(path)
         LOG.debug("all_nvme_devices are %(all_nvme_devices)s",
                   {'all_nvme_devices': all_nvme_devices})
         device_info['path'] = path[0]
@@ -190,8 +188,7 @@ class NVMeConnector(base.BaseLinuxConnector):
         """
         volume_paths = self.get_volume_paths(connection_properties)
         if volume_paths:
-            return self._linuxscsi.extend_volume(
-                volume_paths, use_multipath=self.use_multipath)
+            return self._linuxscsi.extend_volume(volume_paths)
         else:
             LOG.warning("Couldn't find any volume paths on the host to "
                         "extend volume for %(props)s",
