@@ -36,8 +36,7 @@ class NVMeConnectorTestCase(test_connector.ConnectorTestCase):
     def setUp(self):
         super(NVMeConnectorTestCase, self).setUp()
         self.connector = nvme.NVMeConnector(None,
-                                            execute=self.fake_execute,
-                                            use_multipath=False)
+                                            execute=self.fake_execute)
 
     def _nvme_list_cmd(self, *args, **kwargs):
         return FAKE_NVME_LIST_OUTPUT, None
@@ -49,10 +48,9 @@ class NVMeConnectorTestCase(test_connector.ConnectorTestCase):
         self.assertEqual(expected, actual)
 
     @mock.patch.object(nvme.NVMeConnector, '_execute')
-    @mock.patch('time.sleep')
-    def test_get_nvme_devices_raise(self, mock_sleep, mock_execute):
+    def test_get_nvme_devices_raise(self, mock_execute):
         mock_execute.side_effect = putils.ProcessExecutionError
-        self.assertRaises(exception.CommandExecutionFailed,
+        self.assertRaises(putils.ProcessExecutionError,
                           self.connector._get_nvme_devices)
 
     @mock.patch.object(nvme.NVMeConnector, '_get_nvme_devices')
@@ -85,15 +83,14 @@ class NVMeConnectorTestCase(test_connector.ConnectorTestCase):
             run_as_root=True)
 
     @mock.patch.object(nvme.NVMeConnector, '_execute')
-    @mock.patch('time.sleep')
-    def test_connect_volume_raise(self, mock_sleep, mock_execute):
+    def test_connect_volume_raise(self, mock_execute):
         connection_properties = {'target_portal': 'portal',
                                  'target_port': 1,
                                  'nqn': 'nqn.volume_123',
                                  'device_path': '',
                                  'transport_type': 'rdma'}
         mock_execute.side_effect = putils.ProcessExecutionError
-        self.assertRaises(exception.CommandExecutionFailed,
+        self.assertRaises(putils.ProcessExecutionError,
                           self.connector.connect_volume,
                           connection_properties)
 
@@ -116,8 +113,7 @@ class NVMeConnectorTestCase(test_connector.ConnectorTestCase):
 
     @mock.patch.object(nvme.NVMeConnector, '_get_nvme_devices')
     @mock.patch.object(nvme.NVMeConnector, '_execute')
-    @mock.patch('time.sleep')
-    def test_disconnect_volume(self, mock_sleep, mock_execute, mock_devices):
+    def test_disconnect_volume(self, mock_devices, mock_execute):
         connection_properties = {'target_portal': 'portal',
                                  'target_port': 1,
                                  'nqn': 'nqn.volume_123',
@@ -134,9 +130,7 @@ class NVMeConnectorTestCase(test_connector.ConnectorTestCase):
 
     @mock.patch.object(nvme.NVMeConnector, '_get_nvme_devices')
     @mock.patch.object(nvme.NVMeConnector, '_execute')
-    @mock.patch('time.sleep')
-    def test_disconnect_volume_raise(
-            self, mock_sleep, mock_execute, mock_devices):
+    def test_disconnect_volume_raise(self, mock_devices, mock_execute):
         mock_execute.side_effect = putils.ProcessExecutionError
         mock_devices.return_value = '/dev/nvme0n1'
         connection_properties = {'target_portal': 'portal',
@@ -163,11 +157,9 @@ class NVMeConnectorTestCase(test_connector.ConnectorTestCase):
                           self.connector.extend_volume,
                           connection_properties)
 
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'find_multipath_device_path')
     @mock.patch.object(linuxscsi.LinuxSCSI, 'extend_volume')
     @mock.patch.object(nvme.NVMeConnector, 'get_volume_paths')
-    def test_extend_volume(self, mock_volume_paths, mock_scsi_extend,
-                           mock_scsi_find_mpath):
+    def test_extend_volume(self, mock_volume_paths, mock_scsi_extend):
         fake_new_size = 1024
         mock_volume_paths.return_value = ['/dev/vdx']
         mock_scsi_extend.return_value = fake_new_size
@@ -178,4 +170,3 @@ class NVMeConnectorTestCase(test_connector.ConnectorTestCase):
                                  'transport_type': 'rdma'}
         new_size = self.connector.extend_volume(connection_properties)
         self.assertEqual(fake_new_size, new_size)
-        mock_scsi_find_mpath.assert_not_called()
